import { ManagedWorkerRegion } from '../../rest/generated/cloud/data-contracts';
import { z } from 'zod';
export declare const SharedCPUComputeSchema: z.ZodObject<z.objectUtil.extendShape<{
    pool: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    numReplicas: z.ZodDefault<z.ZodNumber>;
    regions: z.ZodOptional<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">>;
    cpus: z.ZodNumber;
}, {
    cpuKind: z.ZodLiteral<"shared">;
    memoryMb: z.ZodEffects<z.ZodNumber, number, number>;
}>, "strip", z.ZodTypeAny, {
    numReplicas: number;
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    pool?: string | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}, {
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    pool?: string | undefined;
    numReplicas?: number | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}>;
export type SharedCPUCompute = z.infer<typeof SharedCPUComputeSchema>;
export declare const PerformanceCPUComputeSchema: z.ZodObject<z.objectUtil.extendShape<{
    pool: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    numReplicas: z.ZodDefault<z.ZodNumber>;
    regions: z.ZodOptional<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">>;
    cpus: z.ZodNumber;
}, {
    cpuKind: z.ZodLiteral<"performance">;
    memoryMb: z.ZodEffects<z.ZodNumber, number, number>;
}>, "strip", z.ZodTypeAny, {
    numReplicas: number;
    cpus: number;
    cpuKind: "performance";
    memoryMb: number;
    pool?: string | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}, {
    cpus: number;
    cpuKind: "performance";
    memoryMb: number;
    pool?: string | undefined;
    numReplicas?: number | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}>;
export type PerformanceCPUCompute = z.infer<typeof PerformanceCPUComputeSchema>;
export declare const GPUComputeSchema: z.ZodObject<z.objectUtil.extendShape<{
    pool: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    numReplicas: z.ZodDefault<z.ZodNumber>;
    regions: z.ZodOptional<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">>;
    cpus: z.ZodNumber;
}, {
    cpuKind: z.ZodLiteral<"shared">;
    gpuKind: z.ZodEnum<["a10", "l40s", "a100-40gb", "a100-80gb"]>;
    regions: z.ZodOptional<z.ZodEffects<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">, ManagedWorkerRegion[], ManagedWorkerRegion[]>>;
    memoryMb: z.ZodEffects<z.ZodNumber, number, number>;
}>, "strip", z.ZodTypeAny, {
    numReplicas: number;
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    gpuKind: "a10" | "l40s" | "a100-40gb" | "a100-80gb";
    pool?: string | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}, {
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    gpuKind: "a10" | "l40s" | "a100-40gb" | "a100-80gb";
    pool?: string | undefined;
    numReplicas?: number | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}>;
export type GPUCompute = z.infer<typeof GPUComputeSchema>;
export declare const ComputeSchema: z.ZodUnion<[z.ZodObject<z.objectUtil.extendShape<{
    pool: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    numReplicas: z.ZodDefault<z.ZodNumber>;
    regions: z.ZodOptional<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">>;
    cpus: z.ZodNumber;
}, {
    cpuKind: z.ZodLiteral<"shared">;
    memoryMb: z.ZodEffects<z.ZodNumber, number, number>;
}>, "strip", z.ZodTypeAny, {
    numReplicas: number;
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    pool?: string | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}, {
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    pool?: string | undefined;
    numReplicas?: number | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}>, z.ZodObject<z.objectUtil.extendShape<{
    pool: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    numReplicas: z.ZodDefault<z.ZodNumber>;
    regions: z.ZodOptional<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">>;
    cpus: z.ZodNumber;
}, {
    cpuKind: z.ZodLiteral<"performance">;
    memoryMb: z.ZodEffects<z.ZodNumber, number, number>;
}>, "strip", z.ZodTypeAny, {
    numReplicas: number;
    cpus: number;
    cpuKind: "performance";
    memoryMb: number;
    pool?: string | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}, {
    cpus: number;
    cpuKind: "performance";
    memoryMb: number;
    pool?: string | undefined;
    numReplicas?: number | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}>, z.ZodObject<z.objectUtil.extendShape<{
    pool: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    numReplicas: z.ZodDefault<z.ZodNumber>;
    regions: z.ZodOptional<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">>;
    cpus: z.ZodNumber;
}, {
    cpuKind: z.ZodLiteral<"shared">;
    gpuKind: z.ZodEnum<["a10", "l40s", "a100-40gb", "a100-80gb"]>;
    regions: z.ZodOptional<z.ZodEffects<z.ZodArray<z.ZodNativeEnum<typeof ManagedWorkerRegion>, "many">, ManagedWorkerRegion[], ManagedWorkerRegion[]>>;
    memoryMb: z.ZodEffects<z.ZodNumber, number, number>;
}>, "strip", z.ZodTypeAny, {
    numReplicas: number;
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    gpuKind: "a10" | "l40s" | "a100-40gb" | "a100-80gb";
    pool?: string | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}, {
    cpus: number;
    cpuKind: "shared";
    memoryMb: number;
    gpuKind: "a10" | "l40s" | "a100-40gb" | "a100-80gb";
    pool?: string | undefined;
    numReplicas?: number | undefined;
    regions?: ManagedWorkerRegion[] | undefined;
}>]>;
export declare const computeHash: (compute: z.infer<typeof ComputeSchema>) => string;
