import { HatchetClient } from '../hatchet-client';
import { Action, ActionListener } from '../dispatcher/action-listener';
import { StepActionEvent, StepActionEventType, GroupKeyActionEvent, GroupKeyActionEventType } from '../../protoc/dispatcher';
import HatchetPromise from '../../util/hatchet-promise/hatchet-promise';
import { Workflow } from '../../workflow';
import { Logger } from '../../util/logger';
import { WebhookHandler } from './handler';
import { WebhookWorkerCreateRequest } from '../rest/generated/data-contracts';
import { z } from 'zod';
import { Context, StepRunFunction } from '../../step';
import { WorkerLabels } from '../dispatcher/dispatcher-client';
import { ComputeSchema } from './compute/compute-config';
type ActionFunction = StepRunFunction<any, any> | ((ctx: any) => string | Promise<string>);
type ActionRegistryRecord = {
    func: ActionFunction;
    compute?: z.infer<typeof ComputeSchema>;
};
export type ActionRegistry = Record<Action['actionId'], ActionRegistryRecord>;
export interface WorkerOpts {
    name: string;
    handleKill?: boolean;
    maxRuns?: number;
    labels?: WorkerLabels;
}
export declare class Worker {
    client: HatchetClient;
    name: string;
    workerId: string | undefined;
    killing: boolean;
    handle_kill: boolean;
    action_registry: ActionRegistry;
    workflow_registry: Workflow[];
    listener: ActionListener | undefined;
    futures: Record<Action['stepRunId'], HatchetPromise<any>>;
    contexts: Record<Action['stepRunId'], Context<any, any>>;
    maxRuns?: number;
    logger: Logger;
    registeredWorkflowPromises: Array<Promise<any>>;
    labels: WorkerLabels;
    constructor(client: HatchetClient, options: {
        name: string;
        handleKill?: boolean;
        maxRuns?: number;
        labels?: WorkerLabels;
    });
    private registerActions;
    getHandler(workflows: Workflow[]): WebhookHandler;
    registerWebhook(webhook: WebhookWorkerCreateRequest): Promise<import("axios").AxiosResponse<import("../rest/generated/data-contracts").WebhookWorkerCreated, any>>;
    /**
     * @deprecated use registerWorkflow instead
     */
    register_workflow(initWorkflow: Workflow): Promise<void>;
    registerWorkflow(initWorkflow: Workflow): Promise<void>;
    registerAction<T, K>(actionId: string, action: StepRunFunction<T, K>, compute?: z.infer<typeof ComputeSchema>): void;
    handleStartStepRun(action: Action): Promise<void>;
    handleStartGroupKeyRun(action: Action): Promise<void>;
    getStepActionEvent(action: Action, eventType: StepActionEventType, payload?: any): StepActionEvent;
    getGroupKeyActionEvent(action: Action, eventType: GroupKeyActionEventType, payload?: any): GroupKeyActionEvent;
    handleCancelStepRun(action: Action): Promise<void>;
    stop(): Promise<void>;
    exitGracefully(handleKill: boolean): Promise<void>;
    start(): Promise<void>;
    handleAction(action: Action): Promise<void>;
    upsertLabels(labels: WorkerLabels): Promise<WorkerLabels>;
}
export {};
